@@ -19,6 +19,8 @@
 
   CONST_HCLUST <- "hclust"
 
+  CONST_AGGEXCLUSTER <- "aggexcluster"
+
   CONST_APCLUSTERK <- "apclusterK"
 
   CONST_AGNES <-"agnes"
@@ -35,6 +37,8 @@
 
   CONST_PAM <- "pam"
 
+  CONST_PVPICK <- "pvpick"
+
   CONST_GMM <- "gmm"
 
   CONST_KMEANS_ARMA <- "kmeans_arma"
